@@ -5,7 +5,10 @@ TAR=../h2database_$VERSION.orig.tar.xz
 DIR=h2database-$VERSION
 TAG=version-$VERSION
 
-svn export http://h2database.googlecode.com/svn/tags/$TAG/h2 $DIR
+mkdir $DIR
+tar -xf $3 --strip-components=2 -C $DIR
+rm -Rf $DIR/service
+
 XZ_OPT=--best tar -c -v -J -f $TAR \
     --exclude '*.jar' \
     --exclude '*.class' \
